==> antd-mobile-1.0.1.tgz: package/lib/icon/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports.description=exports.title=exports["default"]=undefined;var _grid=require('antd-mobile/components/grid');var _grid2=_interopRequireDefault(_grid);var _icon=require('antd-mobile/components/icon');var _icon2=_interopRequireDefault(_icon);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}

var icons=[
'check-circle','check','check-circle-o',
'cross-circle','cross','cross-circle-o',
'up','down','left',
'right','ellipsis','loading'];var

IConDemo=function(_React$Component){(0,_inherits3["default"])(IConDemo,_React$Component);function IConDemo(){(0,_classCallCheck3["default"])(this,IConDemo);return(0,_possibleConstructorReturn3["default"])(this,_React$Component.apply(this,arguments));}IConDemo.prototype.
render=function render(){
var data=icons.map(function(item){return{
icon:_react2["default"].createElement(_icon2["default"],{type:item}),
text:item};}).
concat([{
icon:_react2["default"].createElement(_icon2["default"],{type:'\uE601',size:55,color:'red'}),
text:'自定义图标'}]);

return _react2["default"].createElement(_grid2["default"],{data:data,columnNum:3,hasLine:false});
};return IConDemo;}(_react2["default"].Component);exports["default"]=IConDemo;

var title=exports.title='Icon';
var description=exports.description='Icon Example';

==> antd-mobile-1.1.2.tgz: package/lib/icon/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports.description=exports.title=exports["default"]=undefined;var _grid=require('antd-mobile/components/grid');var _grid2=_interopRequireDefault(_grid);var _icon=require('antd-mobile/components/icon');var _icon2=_interopRequireDefault(_icon);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}

var icons=[
'check-circle','check','check-circle-o',
'cross-circle','cross','cross-circle-o',
'up','down','left',
'right','ellipsis'];var

IConDemo=function(_React$Component){(0,_inherits3["default"])(IConDemo,_React$Component);function IConDemo(){(0,_classCallCheck3["default"])(this,IConDemo);return(0,_possibleConstructorReturn3["default"])(this,_React$Component.apply(this,arguments));}IConDemo.prototype.
render=function render(){
var data=icons.map(function(item){return{
icon:_react2["default"].createElement(_icon2["default"],{type:item}),
text:item};}).
concat([{
icon:_react2["default"].createElement(_icon2["default"],{type:'\uE601',size:55,color:'red'}),
text:'自定义图标'}]);

return _react2["default"].createElement(_grid2["default"],{data:data,columnNum:3,hasLine:false});
};return IConDemo;}(_react2["default"].Component);exports["default"]=IConDemo;

var title=exports.title='Icon';
var description=exports.description='Icon Example';
